@@ -96,110 +96,7 @@ sub clean_qrcode{
     $self->info("清除残留的历史二维码图片");
     unlink $self->qrcode_path or $self->warn("删除二维码图片[ " . $self->qrcode_path . " ]失败: $!");
 }
-sub spawn {
-    my $self = shift;
-    my %opt = @_;
-    require Mojo::Webqq::Run;
-    my $run = Mojo::Webqq::Run->new(ioloop=>$self->ioloop,log=>$self->log);
-    $run->max_forks(delete $opt{max_forks}) if defined $opt{max_forks};
-    $run->spawn(%opt);
-    $run;
-}
-sub mail{
-    my $self  = shift;
-    my $callback ;
-    my $is_blocking = 1;
-    if(ref $_[-1] eq "CODE"){
-        $callback = pop;
-        $is_blocking = 0;
-    }
-    my %opt = @_;
-    #smtp
-    #port
-    #tls
-    #tls_ca
-    #tls_cert
-    #tls_key
-    #user
-    #pass
-    #from
-    #to
-    #cc
-    #subject
-    #charset
-    #html
-    #text
-    #data MIME::Lite产生的发送数据
-    eval{ require Mojo::SMTP::Client; } ;
-    if($@){
-        $self->error("发送邮件，请先安装模块 Mojo::SMTP::Client");
-        return;
-    }
-    my @new = (
-        address => $opt{smtp},
-        port    => $opt{port} || 25,
-        autodie => $is_blocking,
-    );
-    for(qw(tls tls_ca tls_cert tls_key)){
-        push @new, ($_,$opt{$_}) if defined $opt{$_};
-    }
-    my $smtp = Mojo::SMTP::Client->new(@new);
-    unless(defined $smtp){
-        $self->error("Mojo::SMTP::Client客户端初始化失败");
-        return;
-    }
-    my $data;
-    if(defined $opt{data}){$data = $opt{data}}
-    else{
-        my @data;
-        push @data,("From: $opt{from}","To: $opt{to}");
-        push @data,"Cc: $opt{cc}" if defined $opt{cc};
-        require MIME::Base64;
-        my $charset = defined $opt{charset}?$opt{charset}:"UTF-8";
-        push @data,"Subject: =?$charset?B?" . MIME::Base64::encode_base64($opt{subject},"") . "?=";
-        if(defined $opt{text}){
-            push @data,("Content-Type: text/plain; charset=$charset",'',$opt{text});
-        }
-        elsif(defined $opt{html}){
-            push @data,("Content-Type: text/html; charset=$charset",'',$opt{html});
-        }
-        $data = join "\r\n",@data;
-    }
-    if(defined $callback){#non-blocking send
-        $smtp->send(
-            auth    => {login=>$opt{user},password=>$opt{pass}},
-            from    => $opt{from},
-            to      => $opt{to},
-            data    => $data,
-            quit    => 1,
-            sub{
-                my ($smtp, $resp) = @_;
-                if($resp->error){
-                    $self->error("邮件[ To: $opt{to}|Subject: $opt{subject} ]发送失败: " . $resp->error );
-                    $callback->(0,$resp->error) if ref $callback eq "CODE";
-                    return;
-                }
-                else{
-                    $self->debug("邮件[ To: $opt{to}|Subject: $opt{subject} ]发送成功");
-                    $callback->(1) if ref $callback eq "CODE";
-                }
-            },
-        );
-    }
-    else{#blocking send
-        eval{
-            $smtp->send(
-                auth    => {login=>$opt{user},password=>$opt{pass}},
-                from    => $opt{from},
-                to      => $opt{to},
-                data    => $data,
-                quit    => 1,
-            );
-        };
-        return $@?(0,$@):(1,);
-    }
 
-}
 sub timer {
     my $self = shift;
     $self->ioloop->timer(@_);
@@ -208,7 +105,6 @@ sub timer {
 sub interval{
     my $self = shift;
     $self->ioloop->recurring(@_);
-    return $self;
 }
 
 sub exit{
